function [x,pit] = puleni(f,a,b,chyba,maxit)
% [x,pit] = puleni(f,a,b,chzba,maxit)
% numericke reseni rovnice f(x)=0 metodou puleni intervalu
% x     - priblizne reseni
% pit   - pocet pouzitych iteraci
% f     - anonymni funkce
% a     - levy krajni bod intervalu
% b     - pravy krajni bod intervalu
% chyba - max. abs. chyba pro priblizne reseni (implicitne 10^-6)
% maxit - maximalni pocet iteraci (implicitne 50)

if nargin==3
    chyba=0.000001;
    maxit=50;
elseif nargin==4
    maxit=50;
elseif nargin<3
    error('Nedostatek vstupnich parametru!')
end

fa = f(a);
fb = f(b);
x=(a+b)/2;
fx=f(x);

pit = 1;

if fa*fb > 0
    error('Funkcni hodnoty na krajich intervalu nemaji opacna znamenka!');
end

while abs(a-b)>chyba && pit<maxit

end % konec cyklu while

end % konec funkce